#ifndef _LAUCHER_H_
#define _LAUCHER_H_

#include <QWidget>

class QPushButton;
class QHBoxLayout;
class QTextEdit;
class MainWindow;

class Launcher : public QWidget
{
	Q_OBJECT

public:
	Launcher(MainWindow *main);
	void activateButtons(bool activate);

public slots:
	void startXTerm(void);
	void showHelp(void);

private:
        QHBoxLayout *m_layout;
 	enum { PASSWD_BUTTON = 0, XTERM_BUTTON, METHER_BUTTON, HELP_BUTTON,
	       NUM_BUTTONS };
        QPushButton *m_buttons[NUM_BUTTONS];
	QTextEdit *m_helpwindow;
};
#endif
